pub struct DeregisterOnPremisesInstance { /* private fields */ }Expand description
Fluent builder constructing a request to DeregisterOnPremisesInstance.
Deregisters an on-premises instance.
Implementations
sourceimpl DeregisterOnPremisesInstance
impl DeregisterOnPremisesInstance
sourcepub async fn customize(
self
) -> Result<CustomizableOperation<DeregisterOnPremisesInstance, AwsResponseRetryClassifier>, SdkError<DeregisterOnPremisesInstanceError>>
pub async fn customize(
self
) -> Result<CustomizableOperation<DeregisterOnPremisesInstance, AwsResponseRetryClassifier>, SdkError<DeregisterOnPremisesInstanceError>>
Consume this builder, creating a customizable operation that can be modified before being sent. The operation’s inner http::Request can be modified as well.
sourcepub async fn send(
self
) -> Result<DeregisterOnPremisesInstanceOutput, SdkError<DeregisterOnPremisesInstanceError>>
pub async fn send(
self
) -> Result<DeregisterOnPremisesInstanceOutput, SdkError<DeregisterOnPremisesInstanceError>>
Sends the request and returns the response.
If an error occurs, an SdkError will be returned with additional details that
can be matched against.
By default, any retryable failures will be retried twice. Retry behavior is configurable with the RetryConfig, which can be set when configuring the client.
sourcepub fn instance_name(self, input: impl Into<String>) -> Self
pub fn instance_name(self, input: impl Into<String>) -> Self
The name of the on-premises instance to deregister.
sourcepub fn set_instance_name(self, input: Option<String>) -> Self
pub fn set_instance_name(self, input: Option<String>) -> Self
The name of the on-premises instance to deregister.