pub struct Builder { /* private fields */ }Expand description
A builder for BatchGetOnPremisesInstancesInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn instance_names(self, input: impl Into<String>) -> Self
pub fn instance_names(self, input: impl Into<String>) -> Self
Appends an item to instance_names.
To override the contents of this collection use set_instance_names.
The names of the on-premises instances about which to get information. The maximum number of instance names you can specify is 25.
sourcepub fn set_instance_names(self, input: Option<Vec<String>>) -> Self
pub fn set_instance_names(self, input: Option<Vec<String>>) -> Self
The names of the on-premises instances about which to get information. The maximum number of instance names you can specify is 25.
sourcepub fn build(self) -> Result<BatchGetOnPremisesInstancesInput, BuildError>
pub fn build(self) -> Result<BatchGetOnPremisesInstancesInput, BuildError>
Consumes the builder and constructs a BatchGetOnPremisesInstancesInput.