pub struct Builder { /* private fields */ }Expand description
A builder for ListDeploymentConfigsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An identifier returned from the previous ListDeploymentConfigs call. It can be used to return the next set of deployment configurations in the list.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An identifier returned from the previous ListDeploymentConfigs call. It can be used to return the next set of deployment configurations in the list.
sourcepub fn build(self) -> Result<ListDeploymentConfigsInput, BuildError>
pub fn build(self) -> Result<ListDeploymentConfigsInput, BuildError>
Consumes the builder and constructs a ListDeploymentConfigsInput.