pub struct Builder { /* private fields */ }Expand description
A builder for ListDeploymentInstancesInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn deployment_id(self, input: impl Into<String>) -> Self
pub fn deployment_id(self, input: impl Into<String>) -> Self
The unique ID of a deployment.
sourcepub fn set_deployment_id(self, input: Option<String>) -> Self
pub fn set_deployment_id(self, input: Option<String>) -> Self
The unique ID of a deployment.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
An identifier returned from the previous list deployment instances call. It can be used to return the next set of deployment instances in the list.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
An identifier returned from the previous list deployment instances call. It can be used to return the next set of deployment instances in the list.
sourcepub fn instance_status_filter(self, input: InstanceStatus) -> Self
pub fn instance_status_filter(self, input: InstanceStatus) -> Self
Appends an item to instance_status_filter.
To override the contents of this collection use set_instance_status_filter.
A subset of instances to list by status:
-
Pending: Include those instances with pending deployments. -
InProgress: Include those instances where deployments are still in progress. -
Succeeded: Include those instances with successful deployments. -
Failed: Include those instances with failed deployments. -
Skipped: Include those instances with skipped deployments. -
Unknown: Include those instances with deployments in an unknown state.
sourcepub fn set_instance_status_filter(
self,
input: Option<Vec<InstanceStatus>>
) -> Self
pub fn set_instance_status_filter(
self,
input: Option<Vec<InstanceStatus>>
) -> Self
A subset of instances to list by status:
-
Pending: Include those instances with pending deployments. -
InProgress: Include those instances where deployments are still in progress. -
Succeeded: Include those instances with successful deployments. -
Failed: Include those instances with failed deployments. -
Skipped: Include those instances with skipped deployments. -
Unknown: Include those instances with deployments in an unknown state.
sourcepub fn instance_type_filter(self, input: InstanceType) -> Self
pub fn instance_type_filter(self, input: InstanceType) -> Self
Appends an item to instance_type_filter.
To override the contents of this collection use set_instance_type_filter.
The set of instances in a blue/green deployment, either those in the original environment ("BLUE") or those in the replacement environment ("GREEN"), for which you want to view instance information.
sourcepub fn set_instance_type_filter(self, input: Option<Vec<InstanceType>>) -> Self
pub fn set_instance_type_filter(self, input: Option<Vec<InstanceType>>) -> Self
The set of instances in a blue/green deployment, either those in the original environment ("BLUE") or those in the replacement environment ("GREEN"), for which you want to view instance information.
sourcepub fn build(self) -> Result<ListDeploymentInstancesInput, BuildError>
pub fn build(self) -> Result<ListDeploymentInstancesInput, BuildError>
Consumes the builder and constructs a ListDeploymentInstancesInput.