pub struct Builder { /* private fields */ }Expand description
A builder for ListDeploymentTargetsInput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn deployment_id(self, input: impl Into<String>) -> Self
pub fn deployment_id(self, input: impl Into<String>) -> Self
The unique ID of a deployment.
sourcepub fn set_deployment_id(self, input: Option<String>) -> Self
pub fn set_deployment_id(self, input: Option<String>) -> Self
The unique ID of a deployment.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
A token identifier returned from the previous ListDeploymentTargets call. It can be used to return the next set of deployment targets in the list.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
A token identifier returned from the previous ListDeploymentTargets call. It can be used to return the next set of deployment targets in the list.
sourcepub fn target_filters(self, k: TargetFilterName, v: Vec<String>) -> Self
pub fn target_filters(self, k: TargetFilterName, v: Vec<String>) -> Self
Adds a key-value pair to target_filters.
To override the contents of this collection use set_target_filters.
A key used to filter the returned targets. The two valid values are:
-
TargetStatus- ATargetStatusfilter string can beFailed,InProgress,Pending,Ready,Skipped,Succeeded, orUnknown. -
ServerInstanceLabel- AServerInstanceLabelfilter string can beBlueorGreen.
sourcepub fn set_target_filters(
self,
input: Option<HashMap<TargetFilterName, Vec<String>>>
) -> Self
pub fn set_target_filters(
self,
input: Option<HashMap<TargetFilterName, Vec<String>>>
) -> Self
A key used to filter the returned targets. The two valid values are:
-
TargetStatus- ATargetStatusfilter string can beFailed,InProgress,Pending,Ready,Skipped,Succeeded, orUnknown. -
ServerInstanceLabel- AServerInstanceLabelfilter string can beBlueorGreen.
sourcepub fn build(self) -> Result<ListDeploymentTargetsInput, BuildError>
pub fn build(self) -> Result<ListDeploymentTargetsInput, BuildError>
Consumes the builder and constructs a ListDeploymentTargetsInput.