Struct aws_sdk_codedeploy::model::deployment_ready_option::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for DeploymentReadyOption.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn action_on_timeout(self, input: DeploymentReadyAction) -> Self
pub fn action_on_timeout(self, input: DeploymentReadyAction) -> Self
Information about when to reroute traffic from an original environment to a replacement environment in a blue/green deployment.
-
CONTINUE_DEPLOYMENT: Register new instances with the load balancer immediately after the new application revision is installed on the instances in the replacement environment.
-
STOP_DEPLOYMENT: Do not register new instances with a load balancer unless traffic rerouting is started using
ContinueDeployment. If traffic rerouting is not started before the end of the specified wait period, the deployment status is changed to Stopped.
sourcepub fn set_action_on_timeout(self, input: Option<DeploymentReadyAction>) -> Self
pub fn set_action_on_timeout(self, input: Option<DeploymentReadyAction>) -> Self
Information about when to reroute traffic from an original environment to a replacement environment in a blue/green deployment.
-
CONTINUE_DEPLOYMENT: Register new instances with the load balancer immediately after the new application revision is installed on the instances in the replacement environment.
-
STOP_DEPLOYMENT: Do not register new instances with a load balancer unless traffic rerouting is started using
ContinueDeployment. If traffic rerouting is not started before the end of the specified wait period, the deployment status is changed to Stopped.
sourcepub fn wait_time_in_minutes(self, input: i32) -> Self
pub fn wait_time_in_minutes(self, input: i32) -> Self
The number of minutes to wait before the status of a blue/green deployment is changed to Stopped if rerouting is not started manually. Applies only to the STOP_DEPLOYMENT option for actionOnTimeout.
sourcepub fn set_wait_time_in_minutes(self, input: Option<i32>) -> Self
pub fn set_wait_time_in_minutes(self, input: Option<i32>) -> Self
The number of minutes to wait before the status of a blue/green deployment is changed to Stopped if rerouting is not started manually. Applies only to the STOP_DEPLOYMENT option for actionOnTimeout.
sourcepub fn build(self) -> DeploymentReadyOption
pub fn build(self) -> DeploymentReadyOption
Consumes the builder and constructs a DeploymentReadyOption.