Struct aws_sdk_codedeploy::model::time_based_canary::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for TimeBasedCanary.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn canary_percentage(self, input: i32) -> Self
pub fn canary_percentage(self, input: i32) -> Self
The percentage of traffic to shift in the first increment of a TimeBasedCanary deployment.
sourcepub fn set_canary_percentage(self, input: Option<i32>) -> Self
pub fn set_canary_percentage(self, input: Option<i32>) -> Self
The percentage of traffic to shift in the first increment of a TimeBasedCanary deployment.
sourcepub fn canary_interval(self, input: i32) -> Self
pub fn canary_interval(self, input: i32) -> Self
The number of minutes between the first and second traffic shifts of a TimeBasedCanary deployment.
sourcepub fn set_canary_interval(self, input: Option<i32>) -> Self
pub fn set_canary_interval(self, input: Option<i32>) -> Self
The number of minutes between the first and second traffic shifts of a TimeBasedCanary deployment.
sourcepub fn build(self) -> TimeBasedCanary
pub fn build(self) -> TimeBasedCanary
Consumes the builder and constructs a TimeBasedCanary.