pub struct Builder { /* private fields */ }Expand description
A builder for BatchGetApplicationRevisionsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn application_name(self, input: impl Into<String>) -> Self
pub fn application_name(self, input: impl Into<String>) -> Self
The name of the application that corresponds to the revisions.
sourcepub fn set_application_name(self, input: Option<String>) -> Self
pub fn set_application_name(self, input: Option<String>) -> Self
The name of the application that corresponds to the revisions.
sourcepub fn error_message(self, input: impl Into<String>) -> Self
pub fn error_message(self, input: impl Into<String>) -> Self
Information about errors that might have occurred during the API call.
sourcepub fn set_error_message(self, input: Option<String>) -> Self
pub fn set_error_message(self, input: Option<String>) -> Self
Information about errors that might have occurred during the API call.
sourcepub fn revisions(self, input: RevisionInfo) -> Self
pub fn revisions(self, input: RevisionInfo) -> Self
Appends an item to revisions.
To override the contents of this collection use set_revisions.
Additional information about the revisions, including the type and location.
sourcepub fn set_revisions(self, input: Option<Vec<RevisionInfo>>) -> Self
pub fn set_revisions(self, input: Option<Vec<RevisionInfo>>) -> Self
Additional information about the revisions, including the type and location.
sourcepub fn build(self) -> BatchGetApplicationRevisionsOutput
pub fn build(self) -> BatchGetApplicationRevisionsOutput
Consumes the builder and constructs a BatchGetApplicationRevisionsOutput.