pub struct Builder { /* private fields */ }Expand description
A builder for GetDeploymentTargetOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn deployment_target(self, input: DeploymentTarget) -> Self
pub fn deployment_target(self, input: DeploymentTarget) -> Self
A deployment target that contains information about a deployment such as its status, lifecycle events, and when it was last updated. It also contains metadata about the deployment target. The deployment target metadata depends on the deployment target's type (instanceTarget, lambdaTarget, or ecsTarget).
sourcepub fn set_deployment_target(self, input: Option<DeploymentTarget>) -> Self
pub fn set_deployment_target(self, input: Option<DeploymentTarget>) -> Self
A deployment target that contains information about a deployment such as its status, lifecycle events, and when it was last updated. It also contains metadata about the deployment target. The deployment target metadata depends on the deployment target's type (instanceTarget, lambdaTarget, or ecsTarget).
sourcepub fn build(self) -> GetDeploymentTargetOutput
pub fn build(self) -> GetDeploymentTargetOutput
Consumes the builder and constructs a GetDeploymentTargetOutput.