Struct aws_sdk_codedeploy::output::list_deployments_output::Builder
source · pub struct Builder { /* private fields */ }Expand description
A builder for ListDeploymentsOutput.
Implementations
sourceimpl Builder
impl Builder
sourcepub fn deployments(self, input: impl Into<String>) -> Self
pub fn deployments(self, input: impl Into<String>) -> Self
Appends an item to deployments.
To override the contents of this collection use set_deployments.
A list of deployment IDs.
sourcepub fn set_deployments(self, input: Option<Vec<String>>) -> Self
pub fn set_deployments(self, input: Option<Vec<String>>) -> Self
A list of deployment IDs.
sourcepub fn next_token(self, input: impl Into<String>) -> Self
pub fn next_token(self, input: impl Into<String>) -> Self
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list deployments call to return the next set of deployments in the list.
sourcepub fn set_next_token(self, input: Option<String>) -> Self
pub fn set_next_token(self, input: Option<String>) -> Self
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list deployments call to return the next set of deployments in the list.
sourcepub fn build(self) -> ListDeploymentsOutput
pub fn build(self) -> ListDeploymentsOutput
Consumes the builder and constructs a ListDeploymentsOutput.