#[non_exhaustive]pub struct ListOnPremisesInstancesOutput { /* private fields */ }Expand description
Represents the output of the list on-premises instances operation.
Implementations
sourceimpl ListOnPremisesInstancesOutput
impl ListOnPremisesInstancesOutput
sourcepub fn instance_names(&self) -> Option<&[String]>
pub fn instance_names(&self) -> Option<&[String]>
The list of matching on-premises instance names.
sourcepub fn next_token(&self) -> Option<&str>
pub fn next_token(&self) -> Option<&str>
If a large amount of information is returned, an identifier is also returned. It can be used in a subsequent list on-premises instances call to return the next set of on-premises instances in the list.
sourceimpl ListOnPremisesInstancesOutput
impl ListOnPremisesInstancesOutput
sourcepub fn builder() -> Builder
pub fn builder() -> Builder
Creates a new builder-style object to manufacture ListOnPremisesInstancesOutput.