#[non_exhaustive]pub struct ApplicationNameRequiredException {
pub message: Option<String>,
/* private fields */
}Expand description
The minimum number of required application names was not specified.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>The message that corresponds to the exception thrown by CodeDeploy.
Implementations
Sourceimpl ApplicationNameRequiredException
impl ApplicationNameRequiredException
Sourcepub fn builder() -> ApplicationNameRequiredExceptionBuilder
pub fn builder() -> ApplicationNameRequiredExceptionBuilder
Creates a new builder-style object to manufacture ApplicationNameRequiredException.