#[non_exhaustive]pub struct InvalidLoadBalancerInfoException {
pub message: Option<String>,
/* private fields */
}Expand description
An invalid load balancer name, or no load balancer name, was specified.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>The message that corresponds to the exception thrown by CodeDeploy.
Implementations
sourceimpl InvalidLoadBalancerInfoException
impl InvalidLoadBalancerInfoException
sourcepub fn builder() -> InvalidLoadBalancerInfoExceptionBuilder
pub fn builder() -> InvalidLoadBalancerInfoExceptionBuilder
Creates a new builder-style object to manufacture InvalidLoadBalancerInfoException.