#[non_exhaustive]pub struct InvalidRegistrationStatusException {
pub message: Option<String>,
/* private fields */
}Expand description
The registration status was specified in an invalid format.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.message: Option<String>The message that corresponds to the exception thrown by CodeDeploy.
Implementations
Sourceimpl InvalidRegistrationStatusException
impl InvalidRegistrationStatusException
Sourcepub fn builder() -> InvalidRegistrationStatusExceptionBuilder
pub fn builder() -> InvalidRegistrationStatusExceptionBuilder
Creates a new builder-style object to manufacture InvalidRegistrationStatusException.